@@ -84,6 +84,7 @@ PorseleinApp.fixLinks = function()
     }
 };
 
+//Get a variable from the current query string
 PorseleinApp.getQueryVariable = function(variable) {
     var query = window.location.search.substring(1);
     var vars = query.split('&');
@@ -96,6 +97,28 @@ PorseleinApp.getQueryVariable = function(variable) {
     return null
 }
 
+//Add a variable to the query string of the passed URL
+PorseleinApp.addToQueryString = function (url, query)
+{
+    var querystr =  "?"
+    var newQuery = ""
+    var  newURL = url;
+    
+    if (url.indexOf("?") != -1)
+    {
+        querystr = url.substring(url.indexOf("?"));
+        newQuery = querystr + "&" + query;
+        newURL = url.substring(0, url.indexOf("?"));
+    }
+    else
+    {
+        querystr = "?";
+        newQuery = querystr + query;
+    }
+    
+    return newURL+ newQuery;
+};
+
 //Stop bouncing
 PorseleinApp.stopBounce = function ()
 {
@@ -327,122 +350,137 @@ PorseleinApp.fixHeight = function ()
     }
 };
 
+PorseleinApp.fixBackButtonAction = function ()
+{
+    $('.backButton').bind('touchstart', function (e) {
+                    $(this).addClass('active');
+        });
+    $('.backButton').bind('touchend', function (e) {
+                    $(this).removeClass('active');
+        });
+}
+
+//==== Allways on / standby mode =====
+
+//Standby delay in miliseconds
+PorseleinApp.standbyDelay = 300000;
+//The actual timer
+PorseleinApp.standbyTimer = null;
+//Check if the alwaysOn flag is on the query string
+PorseleinApp.isAlwaysOn = PorseleinApp.getQueryVariable('alwaysOn') != null;
+//Check if standby flag is on the query string
+PorseleinApp.isStandby = PorseleinApp.getQueryVariable('standby') != null;
+
+//Adding the variable to store the query string adition on Always On mode
+if (PorseleinApp.isAlwaysOn)
+{
+    PorseleinApp.alwaysOnQuery = "alwaysOn=true";
+}
+else
+{
+    PorseleinApp.alwaysOnQuery = "";
+}
+
+//Standby mode on!
+PorseleinApp.standbyOn = function ()
+{
+   window.location = PorseleinApp.homeURL + (PorseleinApp.isAlwaysOn ? ('?standby=true&'+PorseleinApp.alwaysOnQuery):'');
+}
+
+PorseleinApp.standbyOff = function ()
+{
+    
+    $('#standbyPopup').remove();
+    clearTimeout(PorseleinApp.standbyTimer);
+    PorseleinApp.standbyTimer = setTimeout(PorseleinApp.standbyOn, PorseleinApp.standbyDelay);
+}
+
+
+//Motion sensor
+PorseleinApp.ax_cache = 0
+PorseleinApp.ay_cache = 0
+PorseleinApp.az_cache = 0
+PorseleinApp.motions = 0
+
+PorseleinApp.standbyOffByMotion = function (event)
+{
+    var ax = event.accelerationIncludingGravity.x;
+    var ay = event.accelerationIncludingGravity.y;
+    var az = event.accelerationIncludingGravity.z;
+    
+    if (PorseleinApp.ax_cache == 0 && PorseleinApp.ay_cache == 0 && PorseleinApp.az_cache == 0)
+    {
+        PorseleinApp.ax_cache = ax;
+        PorseleinApp.ay_cache = ay;
+        PorseleinApp.az_cache = az;
+        return;
+    }
+    
+    var xdiff = Math.round(ax) - Math.round(PorseleinApp.ax_cache);
+    var ydiff = Math.round(ay) - Math.round(PorseleinApp.ay_cache);
+    var zdiff = Math.round(az) - Math.round(PorseleinApp.az_cache);
+    
+    PorseleinApp.ax_cache = ax;
+    PorseleinApp.ay_cache = ay;
+    PorseleinApp.az_cache = az;
+    
+    if (Math.abs(xdiff) > 1 || Math.abs(ydiff) > 1 || Math.abs(zdiff) > 1)
+    {
+        PorseleinApp.motions++;
+        if(PorseleinApp.motions > 2)
+        {
+            if (PorseleinApp.motions > 100)
+            {
+                PorseleinApp.motions = 3;
+            }
+            //$('body').prepend($("<p>Motion!!</p>"))
+            PorseleinApp.standbyOff();  
+        }  
+    }
+    
+    
+}
+
+PorseleinApp.ReadAndPassAlwaysOnMode = function ()
+{
+    //var isiPad = navigator.userAgent.match(/iPad/i) != null;
+    //DEBUG
+    var isiPad = true
+    
+    if (isiPad && PorseleinApp.isAlwaysOn)
+    {
+        //Change all the links
+        $('a').each(function ()
+                    {
+                        var href = $(this).attr('href');
+                        var newHref = ""
+                        if (href != "" && href != null)
+                        {
+                            newHref = PorseleinApp.addToQueryString(href, PorseleinApp.alwaysOnQuery);
+                            $(this).attr('href', newHref);
+                        }
+                    });
+        //TODO: Start the timers
+        if (!PorseleinApp.isStandby)
+        {
+            PorseleinApp.standbyTimer = setTimeout(PorseleinApp.standbyOn, PorseleinApp.standbyDelay)
+        }
+        document.addEventListener('click', PorseleinApp.standbyOff);
+        $(window).bind('orientationchange', PorseleinApp.standbyOff);
+        document.addEventListener('touchstart', PorseleinApp.standbyOff);
+        window.ondevicemotion = PorseleinApp.standbyOffByMotion;
+    }
+};
+//=========================
+
 $(function(){
     PorseleinApp.loader();
     PorseleinApp.fixLinks();
     PorseleinApp.fixHeight();
     $(window).resize(PorseleinApp.fixHeight);
+    PorseleinApp.fixBackButtonAction();
+    PorseleinApp.ReadAndPassAlwaysOnMode();
     //PorseleinApp.stopBounce();
     //PorseleinApp.selfScroll();
     //PorseleinApp.iscroll();
-});
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-/*
-// Temporary stuff
-//=================================
-
-//Definition of a page
-function Page ()
-{
-    this.obj = $('<div class="page"></div>');
-    this.loaded = false;
-    this.URL = null;
-}
-
-Page.prototype.load = function ()
-{
-    if (this.URL !== null)
-    {
-        
-    }
-}
-//================
-
-
-//Stores the current pages, basically keeps the content
-PorseleinApp.pages = [];
-
-//Checks for existing pages on the current content and syncs the arry to that
-PorseleinApp.sync = function ()
-{
-    
-}
-
-//Checks if the page exists
-PorseleinApp.find = function()
-{
-    for (page in this.pages)
-    {
-        
-    }
-}
-
-//Ads a page to the end of the stack, returns the position of the new page
-PorseleinApp.addPage = function(page)
-{
-    PorseleinApp.pages.push(page);
-    return PorseleinApp.pages.length -1;
-};
-
-//Removes a page from the stack
-PorseleinApp.removePage = function (position)
-{
-    
-};
-
-//Move a page to a new position
-PorseleinApp.movePage = function(origin, destination)
-{
-    
-};
-
-//Initialize everything and prepare for operation
-PorseleinApp.init = function()
-{
-    
-};
-
-//Touchstart event
-PorseleinApp.touchstart = function (e)
-{
-    
-};
-
-//Touchmove event
-PorseleinApp.touchmove = function(e)
-{
-    
-};
-
-//Register the events
-PorseleinApp.registerEvents = function(e)
-{
-    
-};
-
-//=================================
-*/
\ No newline at end of file
+});
\ No newline at end of file
